/**
 * ProjectLaogai
 *
 * Copyright 2019  <seil0@mosad.xyz>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 */

package org.mosad.seil0.projectlaogai.fragments

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.LinearLayout
import androidx.fragment.app.Fragment
import kotlinx.android.synthetic.main.fragment_mensa.*
import org.jetbrains.anko.doAsync
import org.jetbrains.anko.uiThread
import org.mosad.seil0.projectlaogai.R
import org.mosad.seil0.projectlaogai.controller.CacheController.Companion.mensaCurrentWeek
import org.mosad.seil0.projectlaogai.controller.CacheController.Companion.mensaNextWeek
import org.mosad.seil0.projectlaogai.controller.PreferencesController.Companion.cShowBuffet
import org.mosad.seil0.projectlaogai.hsoparser.MensaWeek
import org.mosad.seil0.projectlaogai.hsoparser.NotRetardedCalendar
import org.mosad.seil0.projectlaogai.uicomponents.DayCardView
import org.mosad.seil0.projectlaogai.uicomponents.MealLinearLayout

/**
 * The mensa controller class
 * contains all needed parts to display and the mensa detail screen
 */
class MensaFragment : Fragment() {

    private lateinit var linLayoutMensaFragment: LinearLayout

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {

        val view: View = inflater.inflate(R.layout.fragment_mensa, container, false)

        linLayoutMensaFragment = view.findViewById(R.id.linLayout_Mensa)

        // add the current week (week starts on sunday)
        val dayCurrent =  if(NotRetardedCalendar().getDayOfWeekIndex() == 6) 0 else NotRetardedCalendar().getDayOfWeekIndex()
        addWeek(mensaCurrentWeek, dayCurrent).get()

        // add the next week
        addWeek(mensaNextWeek, 0).get()

        return view
    }

    /**
     * add all menus from dayStart to Friday for a given week
     */
    private fun addWeek(menusWeek: MensaWeek, dayStart: Int) = doAsync {

        uiThread {

            // only add the days dayStart to Fri since the mensa is closed on Sat/Sun
            for (dayIndex in dayStart..4) {
                var helpMeal = MealLinearLayout(context)
                val dayCardView = DayCardView(context!!)
                dayCardView.setDayHeading(menusWeek.days[dayIndex].meals[0].day)

                for (meal in menusWeek.days[dayIndex].meals) {
                    val mealLayout = MealLinearLayout(context)
                    mealLayout.setMeal(meal)

                    if(meal.heading != "Buffet" || cShowBuffet) {
                        dayCardView.getLinLayoutDay().addView(mealLayout)
                        helpMeal = mealLayout
                    }
                }

                helpMeal.disableDivider()

                if(dayCardView.getLinLayoutDay().childCount > 1)
                    linLayout_Mensa.addView(dayCardView)
            }

        }

    }

}
